@@ -74,7 +74,7 @@ maybe_add_to_list (netrc_entry **newentry, netrc_entry **list)
 }
 
 netrc_entry *
-parse_netrc (char *file)
+netrc_parse (char *file)
 {
     FILE *fp;
     char buf[POPBUFSIZE+1], *p, *tok;
@@ -311,7 +311,7 @@ parse_netrc (char *file)
     free (current);
 
     if (error_flag) {
-	free_netrc(retval);
+	netrc_free(retval);
 	return NULL;
     }
 
@@ -335,7 +335,7 @@ parse_netrc (char *file)
 }
 
 const netrc_entry *
-search_netrc (netrc_entry *list, char *host, char *login)
+netrc_search (netrc_entry *list, char *host, char *login)
 {
     /* Look for the HOST in LIST. */
     while (list)
@@ -353,7 +353,7 @@ search_netrc (netrc_entry *list, char *host, char *login)
 }
 
 void
-free_netrc(netrc_entry *a) {
+netrc_free(netrc_entry *a) {
     while(a) {
 	netrc_entry *n = a->next;
 	xzerofree(a->password);
@@ -394,7 +394,7 @@ int main (int argc, char **argv)
 		 strerror (errno));
     }
 
-    head = parse_netrc(file);
+    head = netrc_parse(file);
     if (!head)
     {
 	fprintf(stderr, "%s: read error or no entries found in %s\n", argv[0], file);
@@ -408,7 +408,7 @@ int main (int argc, char **argv)
 
 	printf("Host: %s, Login: %s\n", host, login);
 	
-	a = search_netrc (head, host, login);
+	a = netrc_search (head, host, login);
 	if (a)
 	{
 	    /* Print out the password (if any). */
@@ -419,7 +419,7 @@ int main (int argc, char **argv)
 	} else
 	    status = EXIT_FAILURE;
 	fputc ('\n', stdout);
-	free_netrc(head);
+	netrc_free(head);
 	exit (status);
     }
 
@@ -447,7 +447,7 @@ int main (int argc, char **argv)
 	fputs ("|\n", stdout);
     }
 
-    free_netrc(head);
+    netrc_free(head);
     exit (0);
 }
 #endif /* STANDALONE */
